#include <stdio.h>
#include <string.h>
#include <stdlib.h>

const long MAX_NUMBER_OF_WORDS = 1010;
const long NUMBER_OF_LETTERS = 26;

class Edge
{
public:
	long nWord;
	long nFirstVertice;
	long nLastVertice;
};

class Vertice
{
public:
	long cEdges;
	long cIncomingEdges;
	Edge edges[MAX_NUMBER_OF_WORDS];
};

class Stack
{
public:
	Edge data[MAX_NUMBER_OF_WORDS];
	long top;
	void Init(){top = 0;}
	Edge Get(){return data[top-1];}
	void Out(){--top;}
	void In(Edge e){data[top++] = e;}
	int notEmpty(){return top > 0;}
	long Length(){return top-1;};
};

long cWords;
char words[MAX_NUMBER_OF_WORDS][25];
int used[MAX_NUMBER_OF_WORDS];

Vertice vertices[NUMBER_OF_LETTERS];

int cmpEdges(const void* a, const void* b)
{
	Edge e1 = *(Edge*)a;
	Edge e2 = *(Edge*)b;
	return strcmp(words[e1.nWord], words[e2.nWord]);
}

Stack way;

int DFS (int nVertice)
{
	way.Init();
	memset(used, 0, sizeof(used));
	Stack stack;
	stack.Init();
	stack.In(vertices[nVertice].edges[0]);
	used[vertices[nVertice].edges[0].nWord] = 1;
	
	while (stack.notEmpty())
	{
		int stepped = 0;
		Edge currentEdge = stack.Get();
		Vertice vertice = vertices[currentEdge.nLastVertice];
		for (long iEdge = 0; iEdge < vertice.cEdges; ++iEdge)
		{
			if (!used[vertice.edges[iEdge].nWord])
			{
				stack.In(vertice.edges[iEdge]);
				stepped = 1;
				used[vertice.edges[iEdge].nWord] = 1;
				break;
			}
		}
		
		if (!stepped)
		{
			stack.Out();
			way.In(currentEdge);
		}
	}

	return way.top == cWords;
}

long MinVertice()
{
	for (long m = 0; m < NUMBER_OF_LETTERS; ++m)
		if (vertices[m].cEdges > 0)
			return m;
	return -1;
}


int main()
{
#ifndef ONLINE_JUDGE
	freopen("input.txt", "rt", stdin);
	freopen("output.txt", "wt", stdout);
#endif

	long cCases, iCase;
	scanf("%ld", &cCases);
	for(iCase = 0; iCase < cCases; ++iCase)
	{
		memset(vertices, 0, sizeof(vertices));
		long iWord;
		long iVertice;
		scanf("%ld\n", &cWords);
		for(iWord = 0; iWord < cWords; ++iWord)
		{
			scanf("%s\n", words[iWord]);
			char firstLetter = words[iWord][0];
			char lastLetter = words[iWord][strlen(words[iWord])-1];
			
			long cEdges = vertices[firstLetter-'a'].cEdges;
			
			vertices[firstLetter-'a'].edges[cEdges].nWord = iWord;
			vertices[firstLetter-'a'].edges[cEdges].nFirstVertice = firstLetter-'a';
			vertices[firstLetter-'a'].edges[cEdges].nLastVertice = lastLetter-'a';
			
			++vertices[firstLetter-'a'].cEdges;
			++vertices[lastLetter-'a'].cIncomingEdges;
		}
		for(iVertice = 0; iVertice < NUMBER_OF_LETTERS; ++iVertice)
		{
			qsort(
				vertices[iVertice].edges, 
				vertices[iVertice].cEdges, 
				sizeof(vertices[iVertice].edges[0]), 
				cmpEdges
				);
		}
		long cOddVertices;
		long nOddVertices[NUMBER_OF_LETTERS];
		for(cOddVertices = iVertice = 0; iVertice < NUMBER_OF_LETTERS; ++iVertice)
		{
			long diff = abs(vertices[iVertice].cEdges - vertices[iVertice].cIncomingEdges);
			if(diff > 1) break;
			if(diff == 0) continue;
			nOddVertices[cOddVertices++] = iVertice;
		}
		if(iVertice < NUMBER_OF_LETTERS || (cOddVertices != 2 && cOddVertices != 0))
		{
			puts("***");
			continue;
		}

		int found;
		if (cOddVertices == 0)
		{
			found = DFS(MinVertice());
		}
		else
		{
			found = DFS(nOddVertices[0]);
			if (!found)
				found = DFS(nOddVertices[1]);
		}

		if (found)
		{
			for (long iEdge = way.Length(); iEdge >= 0; --iEdge)
			{
				printf(words[way.data[iEdge].nWord]);
				if (iEdge > 0)
					putchar('.');
			}
			putchar('\n');
		}
		else
			puts("***");

	}

#ifndef ONLINE_JUDGE
	fclose(stdin);
	fclose(stdout);
#endif
	return 0;
}